module.exports = defineTest({
	description: 'Make sure side-effects are passed along destructuring assignments',
	options: { output: { name: 'bundle' } }
});
